@@ -49,6 +49,7 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->lineEdit_2->setValidator(new QRegExpValidator(regexer_book, ui->lineEdit_2));
     ui->Snap->setValidator(new QRegExpValidator(regexer_snap, ui->Snap));
     ui->Opacity->setValidator(new QRegExpValidator(regexer_opaasi, ui->Opacity));
+    ui->Opacity_top->setValidator(new QRegExpValidator(regexer_opaasi, ui->Opacity_top));
     progress3.setValue(80);
     readgtkrc();
     progress3.setValue(100);
@@ -172,6 +173,7 @@ void MainWindow::writeSettings()
     sett.setValue("appsize", ui->lineEdit->text());
     sett.setValue("booksize", ui->lineEdit_2->text());
     sett.setValue("opacity", ui->Opacity->text());
+    sett.setValue("opacity_top", ui->Opacity_top->text());
 
     QString Icons;
     if ( ui->Icons->checkState() == Qt::Checked ) {
@@ -192,10 +194,12 @@ void MainWindow::readSettings()
     int appsize = sett.value("appsize").toInt();
     int booksize = sett.value("booksize").toInt();
     int opacity = sett.value("opacity").toInt();
+    int opacity_top = sett.value("opacity_top").toInt();
     QString appsizestring = sett.value("appsize").toString();
     QString booksizestring = sett.value("booksize").toString();
     QString snapstring = sett.value("snap").toString();
     QString opacitystring = sett.value("opacity").toString();
+    QString opacitystring_top = sett.value("opacity_top").toString();
     // ui->Icons->setCurrentIndex(icons);
     // ui->Snap->setCurrentIndex(snap);
 
@@ -223,10 +227,15 @@ void MainWindow::readSettings()
     ui->horizontalSlider_3->setValue(snap);
     }
 
- //   if ( opacity > 0 ) {
+    if ( opacity > 0 ) {
     ui->Opacity->setText(opacitystring);
     ui->horizontalSlider_4->setValue(opacity);
- //   }
+    }
+
+    if ( opacity_top > 0 ) {
+    ui->Opacity_top->setText(opacitystring_top);
+    ui->horizontalSlider_5->setValue(opacity_top);
+    }
 
 }
 
@@ -242,6 +251,13 @@ void MainWindow::SetOpacity(QString imagefile, int opacity)
     QPainter p(&transparent);
     p.setCompositionMode(QPainter::CompositionMode_Source);
     p.drawPixmap(0, 0, temp);
+    p.drawPixmap(0, 0, temp);
+    p.drawPixmap(0, 0, temp);
+    p.drawPixmap(0, 0, temp);
+    p.drawPixmap(0, 0, temp);
+    p.drawPixmap(0, 0, temp);
+    p.drawPixmap(0, 0, temp);
+    p.drawPixmap(0, 0, temp);
     p.setCompositionMode(QPainter::CompositionMode_DestinationIn);
     p.fillRect(transparent.rect(), QColor(0, 0, 0, opacity));  // opacity value can be 0-255
     p.end();
@@ -282,7 +298,7 @@ void MainWindow::on_pushButton_clicked()
 
 //        QMaemo5InformationBox::information(this, tr("Creating backups..."), 1);
         progress.setLabelText(tr("Creating backups..."));
-        sleep(2);
+//        sleep(2);
         progress.setValue(4);
         progress.setValue(6);
         progress.setValue(8);
@@ -290,11 +306,12 @@ void MainWindow::on_pushButton_clicked()
         systemcommand << "createbackups";
         QProcess *muoks1 = new QProcess(this);
         muoks1->start("/sbin/launchcustomizer", systemcommand);
+        muoks1->waitForFinished();
         progress.setValue(10);
 
 //        QMaemo5InformationBox::information(this, tr("Setting up font family..."), 1);
         progress.setLabelText(tr("Setting up font family..."));
-        sleep(2);
+//        sleep(2);
         progress.setValue(12);
         progress.setValue(14);
         progress.setValue(16);
@@ -303,11 +320,12 @@ void MainWindow::on_pushButton_clicked()
         systemcommand << "setfontfamily" << ui->Fonter->currentText();
         QProcess *muoks2 = new QProcess(this);
         muoks2->start("/sbin/launchcustomizer", systemcommand);
+        muoks2->waitForFinished();
         progress.setValue(20);
 
 //        QMaemo5InformationBox::information(this, tr("Setting up font sizes..."), 1);
         progress.setLabelText(tr("Setting up font sizes..."));
-        sleep(2);
+//        sleep(2);
         progress.setValue(22);
         progress.setValue(24);
         progress.setValue(26);
@@ -316,11 +334,12 @@ void MainWindow::on_pushButton_clicked()
         systemcommand << "setfontsize" << ui->FontSize->currentText();
         QProcess *muoks3 = new QProcess(this);
         muoks3->start("/sbin/launchcustomizer", systemcommand);
+        muoks3->waitForFinished();
         progress.setValue(30);
 
 //        QMaemo5InformationBox::information(this, tr("Setting up font colors..."), 1);
         progress.setLabelText(tr("Setting up font colors..."));
-        sleep(2);
+//        sleep(2);
         progress.setValue(32);
         progress.setValue(34);
         progress.setValue(36);
@@ -329,11 +348,12 @@ void MainWindow::on_pushButton_clicked()
         systemcommand << "setfontcolors" << f1 << f2 << f3 << f4 << f5 << f6 << f7 << f8;
         QProcess *muoks4 = new QProcess(this);
         muoks4->start("/sbin/launchcustomizer", systemcommand);
+        muoks4->waitForFinished();
         progress.setValue(40);
 
 //        QMaemo5InformationBox::information(this, tr("Setting up icon theme..."), 1);
         progress.setLabelText(tr("Setting up icon theme..."));
-        sleep(2);
+//        sleep(2);
         progress.setValue(42);
         progress.setValue(44);
         progress.setValue(46);
@@ -342,11 +362,12 @@ void MainWindow::on_pushButton_clicked()
         systemcommand << "seticontheme" << ui->Iconset->currentText();
         QProcess *muoks5 = new QProcess(this);
         muoks5->start("/sbin/launchcustomizer", systemcommand);
+        muoks5->waitForFinished();
         progress.setValue(50);
 
  //       QMaemo5InformationBox::information(this, tr("Setting up snap-to-grid..."), 1);
         progress.setLabelText(tr("Setting up snap-to-grid..."));
-        sleep(2);
+//        sleep(2);
         progress.setValue(52);
         progress.setValue(54);
         progress.setValue(56);
@@ -355,11 +376,12 @@ void MainWindow::on_pushButton_clicked()
         systemcommand << "setsnaptogrid" << ui->Snap->text();
         QProcess *muoks6 = new QProcess(this);
         muoks6->start("/sbin/launchcustomizer", systemcommand);
+        muoks6->waitForFinished();
         progress.setValue(60);
 
  //       QMaemo5InformationBox::information(this, tr("Setting up shortcut and bookmark sizes..."), 1);
         progress.setLabelText(tr("Setting up shortcut and bookmark sizes..."));
-        sleep(2);
+//        sleep(2);
         progress.setValue(62);
         progress.setValue(64);
         progress.setValue(66);
@@ -368,12 +390,13 @@ void MainWindow::on_pushButton_clicked()
         systemcommand << "seticonsizes" << ui->lineEdit->text() << ui->lineEdit_2->text() << Icons;
         QProcess *muoks7 = new QProcess(this);
         muoks7->start("/sbin/launchcustomizer", systemcommand);
+        muoks7->waitForFinished();
         progress.setValue(70);
 
         int opasity = ui->Opacity->text().toInt();
+        int opasity_top = ui->Opacity_top->text().toInt();
  //       QMaemo5InformationBox::information(this, tr("Setting up widget opacities..."), 1);
         progress.setLabelText(tr("Setting up widget opacities..."));
-        sleep(2);
         progress.setValue(72);
         progress.setValue(74);
         progress.setValue(76);
@@ -393,6 +416,11 @@ void MainWindow::on_pushButton_clicked()
         SetOpacity("OviRight.png", opasity);
         SetOpacity("RSSAppletHead.png", opasity);
         SetOpacity("WebShortcutAppletBackground.png", opasity);
+        SetOpacity("wmLeftButtonAttached.png", opasity_top);
+        SetOpacity("wmLeftButtonEnd.png", opasity_top);
+        SetOpacity("wmRightButton.png", opasity_top);
+	SetOpacity("wmButtonRightHalf.png", opasity_top);
+	SetOpacity("wmButtonLeftHalf.png", opasity_top);
         progress.setValue(82);
         progress.setValue(84);
         progress.setValue(86);
@@ -402,13 +430,12 @@ void MainWindow::on_pushButton_clicked()
 
             progress.setLabelText(tr("Restarting services..."));
             QMaemo5InformationBox::information(this, tr("Restarting services..."), QMaemo5InformationBox::DefaultTimeout);
-            sleep(2);
             system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
             system("sleep 2");
             system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
             system("sleep 2 && killall hildon-status-menu");
             system("sleep 2 && killall systemui");
-            progress.setValue(100);
+            progress.setValue(99);
             system("sleep 2 && killall hildon-desktop");
             system("killall theme-customizer");
 
@@ -416,7 +443,7 @@ void MainWindow::on_pushButton_clicked()
 
         system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Rebooting in 5 seconds, fasten your seatbelts!'");
         system("/sbin/launchcustomizer rebootnow");
-        progress.setValue(100);
+        progress.setValue(99);
         progress.cancel();
         // oldfonts();
 
@@ -449,6 +476,12 @@ void MainWindow::on_horizontalSlider_4_valueChanged(int value)
     ui->Opacity->setText(slaideri4);
 }
 
+void MainWindow::on_horizontalSlider_5_valueChanged(int value)
+{
+    QString slaideri5 = QString::number(value);
+    ui->Opacity_top->setText(slaideri5);
+}
+
 void MainWindow::on_fontprimary_clicked()
 {
     const QString COLOR_STYLE("QPushButton { color : %2; background-color: %3; border: 2px; border-style: solid; border-color: %4; border-radius: 8px; margin: 5px; padding: 5px;}");
@@ -590,6 +623,13 @@ void MainWindow::on_Opacity_editingFinished()
     ui->horizontalSlider_4->setValue(svalue);
 }
 
+void MainWindow::on_Opacity_top_editingFinished()
+{
+    QString slvalue = ui->Opacity_top->text();
+    int svalue = slvalue.toInt();
+    ui->horizontalSlider_5->setValue(svalue);
+}
+
 void MainWindow::on_checkBoxActivate_stateChanged(int )
 {
     if ( ui->checkBoxActivate->checkState() == Qt::Checked ) {
@@ -658,7 +698,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-24<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-25<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
