@@ -65,6 +65,8 @@ private:
     managepresets* ManWin;
 
 private slots:
+    void on_Opacity_top_editingFinished();
+    void on_horizontalSlider_5_valueChanged(int value);
     void on_actionRestore_theme_files_triggered();
     void loadclicked();
     void delclicked();
