@@ -13,6 +13,11 @@
         <source>Restore theme files</source>
         <translation>Tiedostojen palautus</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Menu bar opacity</source>
+        <translation>Yläpalkin näkyvyys</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Theme Customizer - restore files</source>
