@@ -13,70 +13,75 @@
         <source>Restore theme files</source>
         <translation>Restaurer les fichiers du thème</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Menu bar opacity</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Creating backups...</source>
-        <translation type="unfinished"></translation>
+        <translation>Création de la sauvegarde...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>You must give name for the preset.</source>
-        <translation type="unfinished"></translation>
+        <translation>Vous devez donner un nom à la présélection.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Preset saved!</source>
-        <translation type="unfinished"></translation>
+        <translation>Présélection sauvegarder!</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Preset loaded.</source>
-        <translation type="unfinished"></translation>
+        <translation>Présélection chargée.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Preset deleted.</source>
-        <translation type="unfinished"></translation>
+        <translation>Présélection effacée.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Setting up font family...</source>
-        <translation type="unfinished"></translation>
+        <translation>Application des fontes...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Setting up font sizes...</source>
-        <translation type="unfinished"></translation>
+        <translation>Application de la taille...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Setting up font colors...</source>
-        <translation type="unfinished"></translation>
+        <translation>Application des couleurs...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Setting up icon theme...</source>
-        <translation type="unfinished"></translation>
+        <translation>Application du thème d&apos;icônes...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Setting up snap-to-grid...</source>
-        <translation type="unfinished"></translation>
+        <translation>Application de la taille de la grille...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Setting up shortcut and bookmark sizes...</source>
-        <translation type="unfinished"></translation>
+        <translation>Application de la taille des raccourcis et des favaoris...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Setting up widget opacities...</source>
-        <translation type="unfinished"></translation>
+        <translation>Application de l&apos;opacité...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Restarting services...</source>
-        <translation type="unfinished"></translation>
+        <translation>Redémarage des services...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
